==> onboarding-0.1.0-sources.jar: org/kie/kogito/examples/onboarding/SetupHRProcess.java <==
package org.kie.kogito.examples.onboarding;

import org.jbpm.process.core.datatype.impl.type.ObjectDataType;
import org.jbpm.ruleflow.core.RuleFlowProcessFactory;
import org.drools.core.util.KieFunctions;

@javax.inject.Singleton()
@javax.inject.Named("onboarding.setupHR")
public class SetupHRProcess extends org.kie.kogito.process.impl.AbstractProcess<org.kie.kogito.examples.onboarding.SetupHRModel> {

    @javax.inject.Inject()
    javax.enterprise.inject.Instance<org.kie.api.runtime.process.WorkItemHandler> handlers;

    org.kie.kogito.examples.Application app;

    public SetupHRProcess() {
        this(new org.kie.kogito.examples.Application());
    }

    public SetupHRProcess(org.kie.kogito.examples.Application app) {
        super(app.config().process());
        this.app = app;
    }

    public org.kie.kogito.examples.onboarding.SetupHRProcessInstance createInstance(org.kie.kogito.examples.onboarding.SetupHRModel value) {
        return new org.kie.kogito.examples.onboarding.SetupHRProcessInstance(this, value, this.createLegacyProcessRuntime());
    }

    public org.kie.kogito.examples.onboarding.SetupHRModel createModel() {
        return new org.kie.kogito.examples.onboarding.SetupHRModel();
    }

    public org.kie.kogito.examples.onboarding.SetupHRProcessInstance createInstance(org.kie.kogito.Model value) {
        return this.createInstance((org.kie.kogito.examples.onboarding.SetupHRModel) value);
    }

    public SetupHRProcess configure() {
        return this;
    }

    protected org.kie.api.definition.process.Process legacyProcess() {
        RuleFlowProcessFactory factory = RuleFlowProcessFactory.createProcess("onboarding.setupHR");
        factory.variable("employee", new ObjectDataType("org.kie.kogito.examples.onboarding.Employee"));
        factory.variable("manager", new ObjectDataType("java.lang.String"));
        factory.variable("department", new ObjectDataType("java.lang.String"));
        factory.name("setupHR");
        factory.packageName("org.kie.kogito.examples.onboarding");
        factory.dynamic(false);
        factory.version("1.0");
        factory.visibility("Private");
        factory.metaData("TargetNamespace", "http://www.omg.org/bpmn20");
        org.jbpm.ruleflow.core.factory.EndNodeFactory endNode1 = factory.endNode(1);
        endNode1.name("End");
        endNode1.terminate(false);
        endNode1.done();
        org.jbpm.ruleflow.core.factory.StartNodeFactory startNode2 = factory.startNode(2);
        startNode2.name("Start");
        startNode2.done();
        org.jbpm.ruleflow.core.factory.WorkItemNodeFactory workItemNode3 = factory.workItemNode(3);
        workItemNode3.name("Assign department and manager");
        workItemNode3.workName("AssignDepartmentAndManager");
        workItemNode3.workParameter("TaskName", "AssignDepartmentAndManager");
        workItemNode3.workParameter("Model", "onboarding");
        workItemNode3.workParameter("Namespace", "test");
        workItemNode3.workParameter("Decision", "department");
        workItemNode3.inMapping("employee", "employee");
        workItemNode3.outMapping("manager", "manager");
        workItemNode3.outMapping("department", "department");
        workItemNode3.done();
        factory.connection(3, 1, "_A8AA8CBD-0CC2-4E4A-AF32-415FDFE599F7");
        factory.connection(2, 3, "_ACDDDC63-2696-434C-BE17-FE9B3A39112A");
        factory.validate();
        return factory.getProcess();
    }

    @javax.annotation.PostConstruct()
    public void init() {
        this.configure();
    }
}

==> onboarding-0.2.0-sources.jar: org/kie/kogito/examples/onboarding/SetupHRProcess.java <==
package org.kie.kogito.examples.onboarding;

import org.jbpm.process.core.datatype.impl.type.ObjectDataType;
import org.jbpm.ruleflow.core.RuleFlowProcessFactory;
import org.drools.core.util.KieFunctions;

@javax.inject.Singleton()
@javax.inject.Named("onboarding.setupHR")
public class SetupHRProcess extends org.kie.kogito.process.impl.AbstractProcess<org.kie.kogito.examples.onboarding.SetupHRModel> {

    @javax.inject.Inject()
    javax.enterprise.inject.Instance<org.kie.api.runtime.process.WorkItemHandler> handlers;

    org.kie.kogito.examples.Application app;

    public SetupHRProcess() {
        this(new org.kie.kogito.examples.Application());
    }

    public SetupHRProcess(org.kie.kogito.examples.Application app) {
        super(app.config().process());
        this.app = app;
    }

    public org.kie.kogito.examples.onboarding.SetupHRProcessInstance createInstance(org.kie.kogito.examples.onboarding.SetupHRModel value) {
        return new org.kie.kogito.examples.onboarding.SetupHRProcessInstance(this, value, this.createLegacyProcessRuntime());
    }

    public org.kie.kogito.examples.onboarding.SetupHRModel createModel() {
        return new org.kie.kogito.examples.onboarding.SetupHRModel();
    }

    public org.kie.kogito.examples.onboarding.SetupHRProcessInstance createInstance(org.kie.kogito.Model value) {
        return this.createInstance((org.kie.kogito.examples.onboarding.SetupHRModel) value);
    }

    public SetupHRProcess configure() {
        return this;
    }

    protected org.kie.api.definition.process.Process legacyProcess() {
        RuleFlowProcessFactory factory = RuleFlowProcessFactory.createProcess("onboarding.setupHR");
        factory.variable("employee", new ObjectDataType("org.kie.kogito.examples.onboarding.Employee"));
        factory.variable("manager", new ObjectDataType("java.lang.String"));
        factory.variable("department", new ObjectDataType("java.lang.String"));
        factory.name("setupHR");
        factory.packageName("org.kie.kogito.examples.onboarding");
        factory.dynamic(false);
        factory.version("1.0");
        factory.visibility("Private");
        factory.metaData("TargetNamespace", "http://www.omg.org/bpmn20");
        org.jbpm.ruleflow.core.factory.EndNodeFactory endNode1 = factory.endNode(1);
        endNode1.name("End");
        endNode1.terminate(false);
        endNode1.done();
        org.jbpm.ruleflow.core.factory.StartNodeFactory startNode2 = factory.startNode(2);
        startNode2.name("Start");
        startNode2.done();
        org.jbpm.ruleflow.core.factory.WorkItemNodeFactory workItemNode3 = factory.workItemNode(3);
        workItemNode3.name("Assign department and manager");
        workItemNode3.workName("AssignDepartmentAndManager");
        workItemNode3.workParameter("TaskName", "AssignDepartmentAndManager");
        workItemNode3.workParameter("Model", "onboarding");
        workItemNode3.workParameter("Namespace", "test");
        workItemNode3.workParameter("Decision", "department");
        workItemNode3.inMapping("employee", "employee");
        workItemNode3.outMapping("manager", "manager");
        workItemNode3.outMapping("department", "department");
        workItemNode3.done();
        workItemNode3.metaData("UniqueId", "_C2C840B8-C669-4134-91DD-81B664982F57");
        workItemNode3.metaData("elementname", "Assign department and manager");
        workItemNode3.metaData("x", 244);
        workItemNode3.metaData("width", 154);
        workItemNode3.metaData("y", 77);
        workItemNode3.metaData("height", 102);
        factory.connection(3, 1, "_A8AA8CBD-0CC2-4E4A-AF32-415FDFE599F7");
        factory.connection(2, 3, "_ACDDDC63-2696-434C-BE17-FE9B3A39112A");
        factory.validate();
        return factory.getProcess();
    }

    @javax.annotation.PostConstruct()
    public void init() {
        this.configure();
    }
}
